# Test Coverage Report: excluded packages and modules

Generated: Wed 2012-04-11 05:19 CDT

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- markupmirror.__init__
- markupmirror.feincms.__init__
- markupmirror.markup.__init__
- markupmirror.models
- markupmirror.settings
- markupmirror.tests
- markupmirror.urls

Back to index.